﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Printing;
using Infragistics.Controls.Barcodes;
using Infragistics.Imaging;
using System.Windows.Media.Imaging;
using System.IO;

namespace XamBarcode
{
    public partial class MainPage : UserControl
    {
        bool _changed;
        public MainPage()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            //assign a default value
            this.userInput.Text = "52421654605";
        }

        private void SaveButton_Click(object sender, RoutedEventArgs e)
        {
            WriteableBitmap bitmap = new WriteableBitmap(this.printGrid, null);
            // set up save file dialog
            SaveFileDialog saveDialog = new SaveFileDialog();
            saveDialog.Filter = "JPG (*.jpg)|*.jpg"; ;
            saveDialog.DefaultExt = "jpg";
            if (saveDialog.ShowDialog() == true)
            {
                //encode with the desired format and quality
                using (Stream stream = saveDialog.OpenFile())
                {
                    Infragistics.Imaging.JpegImageEncoder jpgEncoder = new Infragistics.Imaging.JpegImageEncoder();
                    List<EncodingProperty> qualityList = new List<EncodingProperty>();
                    qualityList.Add(new JpegQualityProperty() { Quality = 100 });
                    jpgEncoder.Encode(bitmap, qualityList, stream);
                }
            }
        }

        private void PrintButton_Click(object sender, RoutedEventArgs e)
        {
            //print document and event handles
            PrintDocument printDocument = new PrintDocument();

            printDocument.BeginPrint += (s, args) =>
            {
                //turn text off if it's visible
                if (this.textToggle.IsChecked == true)
                {
                    this.textToggle.IsChecked = false;
                    _changed = true;
                }
            };

            printDocument.PrintPage += (s, args) =>
            {
                ScaleTransform transform = FitToPage(args.PrintableArea);
                //print
                args.PageVisual = this.printGrid;
                args.PageVisual.RenderTransform = transform;
                
            };

            printDocument.EndPrint += (s, args) =>
            {
                // set text back on if it was removed for printing
                if (_changed)
                {
                    this.textToggle.IsChecked = true;
                    _changed = false;
                }
                //clear the scaling if any
                printGrid.ClearValue(FrameworkElement.RenderTransformProperty);
            };
            // start the printing process
            printDocument.Print("Document");
        }

        /// <summary>
        /// Set up a Scale transform if needed to fit the contents to the printable area
        /// </summary>
        /// <param name="size"></param>
        /// <returns></returns>
        private ScaleTransform FitToPage(Size size)
        {
            ScaleTransform resultingTransform = new ScaleTransform();
            //check if the barcodes grid will fit in the printable area
            if (size.Width < printGrid.ActualWidth)
            {
                //if not scale it
                resultingTransform.ScaleX = size.Width / printGrid.ActualWidth;
                resultingTransform.ScaleY = size.Width / printGrid.ActualWidth;
                return resultingTransform;
            }
            return null;
        }

    }
}
